pub struct Canonical<C1, C2>(/* private fields */);Trait Implementations
Sourceimpl<C1, C2> ElasticHyperviscous for Canonical<C1, C2>where
C1: Elastic,
C2: Hyperviscous,
impl<C1, C2> ElasticHyperviscous for Canonical<C1, C2>where
C1: Elastic,
C2: Hyperviscous,
Sourcefn dissipation_potential(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<Quantity<Dissipation>, ConstitutiveError>
fn dissipation_potential( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<Quantity<Dissipation>, ConstitutiveError>
Calculates and returns the dissipation potential. Read more
Sourcefn internal_dissipation(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<Quantity<Dissipation>, ConstitutiveError>
fn internal_dissipation( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<Quantity<Dissipation>, ConstitutiveError>
Calculates and returns the internal dissipation. Read more
Sourceimpl<C1, C2> ElasticPlasticOrViscoplastic for Canonical<C1, C2>
impl<C1, C2> ElasticPlasticOrViscoplastic for Canonical<C1, C2>
Sourcefn cauchy_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<CauchyStress, ConstitutiveError>
fn cauchy_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<CauchyStress, ConstitutiveError>
Calculates and returns the Cauchy stress. Read more
Sourcefn cauchy_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<CauchyTangentStiffness, ConstitutiveError>
fn cauchy_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<CauchyTangentStiffness, ConstitutiveError>
Calculates and returns the tangent stiffness associated with the Cauchy stress. Read more
Sourcefn first_piola_kirchhoff_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<FirstPiolaKirchhoffStress, ConstitutiveError>
fn first_piola_kirchhoff_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<FirstPiolaKirchhoffStress, ConstitutiveError>
Calculates and returns the first Piola-Kirchhoff stress. Read more
Sourcefn first_piola_kirchhoff_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<FirstPiolaKirchhoffTangentStiffness, ConstitutiveError>
fn first_piola_kirchhoff_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<FirstPiolaKirchhoffTangentStiffness, ConstitutiveError>
Calculates and returns the tangent stiffness associated with the first Piola-Kirchhoff stress. Read more
Sourcefn second_piola_kirchhoff_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<SecondPiolaKirchhoffStress, ConstitutiveError>
fn second_piola_kirchhoff_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<SecondPiolaKirchhoffStress, ConstitutiveError>
Calculates and returns the second Piola-Kirchhoff stress. Read more
Sourcefn second_piola_kirchhoff_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<SecondPiolaKirchhoffTangentStiffness, ConstitutiveError>
fn second_piola_kirchhoff_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<SecondPiolaKirchhoffTangentStiffness, ConstitutiveError>
Calculates and returns the tangent stiffness associated with the second Piola-Kirchhoff stress. Read more
Sourcefn mandel_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<MandelStressElastic, ConstitutiveError>
fn mandel_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<MandelStressElastic, ConstitutiveError>
Calculates and returns the Mandel stress. Read more
Sourceimpl<C1, C2, Y2> ElasticViscoplastic<Y2> for Canonical<C1, C2>
impl<C1, C2, Y2> ElasticViscoplastic<Y2> for Canonical<C1, C2>
Sourcefn internal_dissipation(
&self,
deformation_gradient: &DeformationGradient,
state_variables: &ViscoplasticStateVariables<Y>,
) -> Result<Quantity<Dissipation>, ConstitutiveError>
fn internal_dissipation( &self, deformation_gradient: &DeformationGradient, state_variables: &ViscoplasticStateVariables<Y>, ) -> Result<Quantity<Dissipation>, ConstitutiveError>
Calculates and returns the internal dissipation. Read more
Sourcefn state_variables_evolution(
&self,
deformation_gradient: &DeformationGradient,
state_variables: &ViscoplasticStateVariables<Y>,
) -> Result<ViscoplasticEvolution<Y>, ConstitutiveError>
fn state_variables_evolution( &self, deformation_gradient: &DeformationGradient, state_variables: &ViscoplasticStateVariables<Y>, ) -> Result<ViscoplasticEvolution<Y>, ConstitutiveError>
Calculates and returns the evolution of the state variables.
Sourceimpl<C1, C2, Y2> HyperelasticViscoplastic<Y2> for Canonical<C1, C2>
impl<C1, C2, Y2> HyperelasticViscoplastic<Y2> for Canonical<C1, C2>
Sourcefn helmholtz_free_energy_density(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_p: &DeformationGradientPlastic,
) -> Result<Quantity<EnergyDensity>, ConstitutiveError>
fn helmholtz_free_energy_density( &self, deformation_gradient: &DeformationGradient, deformation_gradient_p: &DeformationGradientPlastic, ) -> Result<Quantity<EnergyDensity>, ConstitutiveError>
Calculates and returns the Helmholtz free energy density. Read more
Sourceimpl<C1, C2> Hyperviscoelastic for Canonical<C1, C2>where
C1: Hyperelastic,
C2: Hyperviscous,
impl<C1, C2> Hyperviscoelastic for Canonical<C1, C2>where
C1: Hyperelastic,
C2: Hyperviscous,
Sourcefn helmholtz_free_energy_density(
&self,
deformation_gradient: &DeformationGradient,
) -> Result<Quantity<EnergyDensity>, ConstitutiveError>
fn helmholtz_free_energy_density( &self, deformation_gradient: &DeformationGradient, ) -> Result<Quantity<EnergyDensity>, ConstitutiveError>
Calculates and returns the Helmholtz free energy density. Read more
Sourceimpl<C1, C2> Hyperviscous for Canonical<C1, C2>where
C1: Elastic,
C2: Hyperviscous,
impl<C1, C2> Hyperviscous for Canonical<C1, C2>where
C1: Elastic,
C2: Hyperviscous,
Sourcefn viscous_dissipation(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<Quantity<Dissipation>, ConstitutiveError>
fn viscous_dissipation( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<Quantity<Dissipation>, ConstitutiveError>
Calculates and returns the viscous dissipation. Read more
Sourceimpl<C1, C2> Plastic for Canonical<C1, C2>
impl<C1, C2> Plastic for Canonical<C1, C2>
Sourcefn initial_yield_stress(&self) -> Quantity<Stress>
fn initial_yield_stress(&self) -> Quantity<Stress>
Returns the initial yield stress.
Sourcefn hardening_slope(&self) -> Quantity<Stress>
fn hardening_slope(&self) -> Quantity<Stress>
Returns the isotropic hardening slope.
Sourcefn yield_stress(
&self,
equivalent_plastic_strain: Quantity,
) -> Result<Quantity<Stress>, ConstitutiveError>
fn yield_stress( &self, equivalent_plastic_strain: Quantity, ) -> Result<Quantity<Stress>, ConstitutiveError>
Calculates and returns the yield stress. Read more
Sourceimpl<C1, C2> Solid for Canonical<C1, C2>
impl<C1, C2> Solid for Canonical<C1, C2>
Sourcefn bulk_modulus(&self) -> Quantity<Stress>
fn bulk_modulus(&self) -> Quantity<Stress>
Returns the bulk modulus.
Sourcefn shear_modulus(&self) -> Quantity<Stress>
fn shear_modulus(&self) -> Quantity<Stress>
Returns the shear modulus.
Sourcefn jacobian<I, J>(
&self,
deformation_gradient: &DeformationGradientGeneral<I, J>,
) -> Result<Scalar, ConstitutiveError>
fn jacobian<I, J>( &self, deformation_gradient: &DeformationGradientGeneral<I, J>, ) -> Result<Scalar, ConstitutiveError>
Calculates and returns the Jacobian.
Sourceimpl<C1, C2> Viscoelastic for Canonical<C1, C2>
impl<C1, C2> Viscoelastic for Canonical<C1, C2>
Sourcefn cauchy_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<CauchyStress, ConstitutiveError>
fn cauchy_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<CauchyStress, ConstitutiveError>
Calculates and returns the Cauchy stress. Read more
Sourcefn cauchy_rate_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<CauchyRateTangentStiffness, ConstitutiveError>
fn cauchy_rate_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<CauchyRateTangentStiffness, ConstitutiveError>
Calculates and returns the rate tangent stiffness associated with the Cauchy stress. Read more
Sourcefn first_piola_kirchhoff_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<FirstPiolaKirchhoffStress, ConstitutiveError>
fn first_piola_kirchhoff_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<FirstPiolaKirchhoffStress, ConstitutiveError>
Calculates and returns the first Piola-Kirchhoff stress. Read more
Sourcefn first_piola_kirchhoff_rate_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<FirstPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
fn first_piola_kirchhoff_rate_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<FirstPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
Calculates and returns the rate tangent stiffness associated with the first Piola-Kirchhoff stress. Read more
Sourcefn second_piola_kirchhoff_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<SecondPiolaKirchhoffStress, ConstitutiveError>
fn second_piola_kirchhoff_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<SecondPiolaKirchhoffStress, ConstitutiveError>
Calculates and returns the second Piola-Kirchhoff stress. Read more
Sourcefn second_piola_kirchhoff_rate_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<SecondPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
fn second_piola_kirchhoff_rate_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<SecondPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
Calculates and returns the rate tangent stiffness associated with the second Piola-Kirchhoff stress. Read more
Sourceimpl<C1, C2, Y2> Viscoplastic<Y2> for Canonical<C1, C2>
impl<C1, C2, Y2> Viscoplastic<Y2> for Canonical<C1, C2>
Sourcefn initial_state(&self) -> ViscoplasticStateVariables<Y2>
fn initial_state(&self) -> ViscoplasticStateVariables<Y2>
Returns the initial state of the variables.
Sourcefn plastic_evolution(
&self,
mandel_stress: MandelStressElastic,
state_variables: &ViscoplasticStateVariables<Y2>,
) -> Result<ViscoplasticEvolution<Y2>, ConstitutiveError>
fn plastic_evolution( &self, mandel_stress: MandelStressElastic, state_variables: &ViscoplasticStateVariables<Y2>, ) -> Result<ViscoplasticEvolution<Y2>, ConstitutiveError>
Calculates and returns the plastic evolution. Read more
Sourcefn plastic_stretching_rate(
&self,
deviatoric_mandel_stress: MandelStressElastic,
yield_stress: Quantity<Stress>,
) -> Result<StretchingRatePlastic, ConstitutiveError>
fn plastic_stretching_rate( &self, deviatoric_mandel_stress: MandelStressElastic, yield_stress: Quantity<Stress>, ) -> Result<StretchingRatePlastic, ConstitutiveError>
Calculates and returns the rate of plastic stretching. Read more
Sourcefn dissipation_potential(
&self,
plastic_stretching_rate: StretchingRatePlastic,
yield_stress: Quantity<Stress>,
) -> Result<Quantity<Dissipation>, ConstitutiveError>
fn dissipation_potential( &self, plastic_stretching_rate: StretchingRatePlastic, yield_stress: Quantity<Stress>, ) -> Result<Quantity<Dissipation>, ConstitutiveError>
Calculates and returns the dissipation potential. Read more
Sourcefn dual_dissipation_potential(
&self,
deviatoric_mandel_stress: MandelStressElastic,
yield_stress: Quantity<Stress>,
) -> Result<Quantity<Dissipation>, ConstitutiveError>
fn dual_dissipation_potential( &self, deviatoric_mandel_stress: MandelStressElastic, yield_stress: Quantity<Stress>, ) -> Result<Quantity<Dissipation>, ConstitutiveError>
Calculates and returns the dual dissipation potential. Read more
Sourcefn rate_sensitivity(&self) -> Scalar
fn rate_sensitivity(&self) -> Scalar
Returns the rate_sensitivity parameter.
Sourcefn reference_flow_rate(&self) -> Quantity<Rate>
fn reference_flow_rate(&self) -> Quantity<Rate>
Returns the reference flow rate.
Sourcefn plastic_stretching_rate_tangent(
&self,
deviatoric_mandel_stress: &MandelStressElastic,
yield_stress: Quantity<Stress>,
) -> Result<StretchingRatePlasticTangent, ConstitutiveError>
fn plastic_stretching_rate_tangent( &self, deviatoric_mandel_stress: &MandelStressElastic, yield_stress: Quantity<Stress>, ) -> Result<StretchingRatePlasticTangent, ConstitutiveError>
Calculates and returns the tangent of the plastic stretching rate with
respect to the deviatoric Mandel stress. Read more
Sourcefn plastic_stretching_rate_tangent_yield(
&self,
deviatoric_mandel_stress: MandelStressElastic,
yield_stress: Quantity<Stress>,
) -> Result<StretchingRatePlasticTangentYield, ConstitutiveError>
fn plastic_stretching_rate_tangent_yield( &self, deviatoric_mandel_stress: MandelStressElastic, yield_stress: Quantity<Stress>, ) -> Result<StretchingRatePlasticTangentYield, ConstitutiveError>
Calculates and returns the tangent of the plastic stretching rate with
respect to the yield stress. Read more
Sourceimpl<C1, C2> Viscous for Canonical<C1, C2>
impl<C1, C2> Viscous for Canonical<C1, C2>
Sourcefn bulk_viscosity(&self) -> Quantity<Viscosity>
fn bulk_viscosity(&self) -> Quantity<Viscosity>
Returns the bulk viscosity.
Sourcefn shear_viscosity(&self) -> Quantity<Viscosity>
fn shear_viscosity(&self) -> Quantity<Viscosity>
Returns the shear viscosity.
Sourcefn viscous_cauchy_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<CauchyStress, ConstitutiveError>
fn viscous_cauchy_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<CauchyStress, ConstitutiveError>
Calculates and returns the viscous Cauchy stress. Read more
Sourcefn viscous_cauchy_rate_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<CauchyRateTangentStiffness, ConstitutiveError>
fn viscous_cauchy_rate_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<CauchyRateTangentStiffness, ConstitutiveError>
Calculates and returns the rate tangent stiffness associated with the viscous Cauchy stress. Read more
Sourcefn viscous_first_piola_kirchhoff_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<FirstPiolaKirchhoffStress, ConstitutiveError>
fn viscous_first_piola_kirchhoff_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<FirstPiolaKirchhoffStress, ConstitutiveError>
Calculates and returns the viscous first Piola-Kirchhoff stress. Read more
Sourcefn viscous_first_piola_kirchhoff_rate_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<FirstPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
fn viscous_first_piola_kirchhoff_rate_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<FirstPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
Calculates and returns the rate tangent stiffness associated with the viscous first Piola-Kirchhoff stress. Read more
Sourcefn viscous_second_piola_kirchhoff_stress(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<SecondPiolaKirchhoffStress, ConstitutiveError>
fn viscous_second_piola_kirchhoff_stress( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<SecondPiolaKirchhoffStress, ConstitutiveError>
Calculates and returns the viscous second Piola-Kirchhoff stress. Read more
Sourcefn viscous_second_piola_kirchhoff_rate_tangent_stiffness(
&self,
deformation_gradient: &DeformationGradient,
deformation_gradient_rate: &DeformationGradientRate,
) -> Result<SecondPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
fn viscous_second_piola_kirchhoff_rate_tangent_stiffness( &self, deformation_gradient: &DeformationGradient, deformation_gradient_rate: &DeformationGradientRate, ) -> Result<SecondPiolaKirchhoffRateTangentStiffness, ConstitutiveError>
Calculates and returns the rate tangent stiffness associated with the viscous second Piola-Kirchhoff stress. Read more